@@ -1,13 +1,14 @@
-package CommonMark;
 use 5.008;
 use strict;
 use warnings;
 
 use XSLoader;
 
-our $VERSION = '0.210000';
+our $VERSION = '0.210001';
 XSLoader::load('CommonMark', $VERSION);
 
+package CommonMark;
+
 use constant {
     NODE_NONE        =>  0,
     NODE_DOCUMENT    =>  1,
@@ -51,13 +52,21 @@ use constant {
     OPT_SAFE          => 32,
 };
 
+my @option_map = (
+    sourcepos     =>  1,
+    hardbreaks    =>  2,
+    normalize     =>  4,
+    smart         =>  8,
+    validate_utf8 => 16,
+    safe          => 32,
+);
+
 sub parse {
     my ($class, %opts) = @_;
 
-    my ($string, $file, $smart) = @opts{ qw(string file smart) };
+    my ($string, $file) = @opts{ qw(string file) };
 
-    my $parser_opts = 0;
-    $parser_opts |= OPT_SMART if $smart;
+    my $parser_opts = _extract_opts(\%opts);
 
     my $doc;
     if (defined($string)) {
@@ -75,6 +84,19 @@ sub parse {
     return $doc;
 }
 
+sub _extract_opts {
+    my $hash = shift;
+
+    my $int = 0;
+
+    for (my $i = 0; $i < @option_map; $i += 2) {
+        my ($name, $val) = @option_map[$i,$i+1];
+        $int |= $val if $hash->{$name};
+    }
+
+    return $int;
+}
+
 sub create_document {
     my (undef, %opts) = @_;
     my $node = CommonMark::Node->new(NODE_DOCUMENT);
@@ -251,5 +273,27 @@ sub _add_link_opts {
     return _add_children_or_text($node, $opts);
 }
 
+package CommonMark::Node;
+
+sub render {
+    my ($self, %opts) = @_;
+
+    my $format = $opts{format};
+    die("must provide format")
+        if !defined($format);
+    my $method = "render_$format";
+
+    my $render_opts = CommonMark::_extract_opts(\%opts);
+
+    if ($format =~ /^(html|xml)\z/) {
+        return $self->$method($render_opts);
+    }
+    if ($format =~ /^(commonmark|latex|man)\z/) {
+        return $self->$method($render_opts, $opts{width});
+    }
+
+    die("invalid format '$format'");
+}
+
 1;
 
